@@ -30,7 +30,7 @@ def get_git_info(git_config, remote):
     # https://gitlab.stonebranch.com/integration-prototypes/ue-talend-cloud.git
 
 def parse_repository_full_path(repository_name, groups, group_mapping):
-    result = ""
+    result = repository = ""
     for group in groups:
         if isinstance(group, str):
             group_path = group
@@ -41,14 +41,17 @@ def parse_repository_full_path(repository_name, groups, group_mapping):
             # get the most matched group
             if len(group_path) > len(result):
                 result = group_path
+                repository = repository_name[len(result)+1:]
     
+    logging.debug(f"Group found: {result}")
     if result in group_mapping:
         result = group_mapping.get(result)
-
+        logging.debug(f"Group found in config: {result}")
+    
     if len(result) > 0:
-        return result, repository_name[len(result)+1:]
+        return result, repository
     else:
-        return result, repository_name[len(result):]
+        return None, repository_name
 
 class HtttpClient():
     def __init__(self, base_url, credentials, ssl_verify=False, resource_prefix="/") -> None:
@@ -252,12 +255,12 @@ class Jenkins():
     def get_url(self, group_name, repository_name):
         return f"{self.base_url}/project/{group_name}/{repository_name}"
 
-    def create_job(self, group_name, repository_name, description, gitlab_url):
+    def create_job(self, group_name, repository_name, description, gitlab_url, gitlab_repository_name):
         repository_full_name = f"{group_name}/{repository_name}"
-        config = self.get_default_job_config(gitlab_url, group_name, repository_name, description)
+        config = self.get_default_job_config(gitlab_url, group_name, repository_name, description, gitlab_repository_name)
         self.jnks.create_job(repository_full_name, config)
 
-    def get_default_job_config(self, gitlab_url, group_name, repository_name, description):
+    def get_default_job_config(self, gitlab_url, group_name, repository_name, description, gitlab_repository_name):
         DEFAULT_CONFIG = """<?xml version='1.1' encoding='UTF-8'?>
 <flow-definition plugin="workflow-job@2.42">
   <actions>
@@ -346,9 +349,8 @@ class Jenkins():
   <triggers/>
   <disabled>false</disabled>
 </flow-definition>"""
-        repository = f"{group_name}/{repository_name}"
         return DEFAULT_CONFIG.format(
-            repository=repository,
+            repository=gitlab_repository_name,
             description=description,
             token="{AQAAABAAAAAwn0PMV7WTFCnRSkwbTfvm7603mkro7e+5PvP0NTkPaQIr4W1q6U2c6FvDwBq3Uq+PV3zDPI4vRD+YohxEdVgxRg==}",
             gitlab_url=gitlab_url)
\ No newline at end of file
