@@ -160,8 +160,12 @@ class Quip:
             else:
                 logging.error("You are not in a project folder. Please specify the project name.")
 
-        if "template" in dir(args) and args.template == False and args.name.startswith("ut-"):
+        if "template" not in dir(args):
+            args.template = False
+        elif args.template is False and args.name.startswith("ut-"):
             args.template = True
+        elif args.name.startswith("ue-"):
+            args.template = False
         
         logging.info(f"The project is template={args.template}")
         return args
